@@ -1,11 +1,8 @@
 # Source https://github.com/mlevans/leaflet-hash
 hashDependency <- function() {
   list(
-    htmltools::htmlDependency(
-      "hash",version = "0.2.1",
-      system.file("htmlwidgets/lib/hash", package = "leaflet.extras"),
-      script = c("leaflet-hash.js")
-    )
+    # // "leaflet-hash": "github:PowerPan/leaflet-hash#4020d13",
+    html_dep_prod("lfx-hash", "1.0.1")
   )
 }
 
@@ -15,11 +12,10 @@ hashDependency <- function() {
 #' @rdname leaflethash
 #' @export
 #' @examples
-#' \dontrun{
-#' leaflet() %>% addTiles() %>%
+#' leaflet() %>%
+#'   addTiles() %>%
 #'   addHash()
-#' }
 addHash <- function(map) {
   map$dependencies <- c(map$dependencies, hashDependency())
-  htmlwidgets::onRender(map,JS("function(el,x,data){var hash = new L.Hash(this);}"))
+  htmlwidgets::onRender(map, JS("function(el,x,data){var hash = new L.Hash(this);}"))
 }
